##################
Instrument classes
##################

.. autoclass:: pymeasure.instruments.common_base.CommonBase
    :members:

.. autoclass:: pymeasure.instruments.Instrument
    :members:

.. autoclass:: pymeasure.instruments.Channel
    :members:

.. autoclass:: pymeasure.instruments.fakes.FakeInstrument
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.fakes.SwissArmyFake
    :members:
    :show-inheritance:
